@@ -16,12 +16,12 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *  Authors: Adam Israel <adam@battleaxe.net>
  *           Stefano Karapetsas <stefano@karapetsas.com>
  */
- 
+
 #include <config.h>
 #include <string.h>
 #include <gio/gio.h>
@@ -42,7 +42,6 @@ set_wallpaper_callback (CajaMenuItem *item,
 {
     GList *files;
     GSettings *settings;
-    GError *err;
     CajaFileInfo *file;
     gchar *uri;
     gchar *filename;
@@ -60,22 +59,19 @@ set_wallpaper_callback (CajaMenuItem *item,
     g_object_unref (settings);
     g_free (filename);
     g_free (uri);
-    
+
 }
 
 static gboolean
 is_image (CajaFileInfo *file)
 {
-    gchar *mimeType;
+    gchar   *mimeType;
     gboolean isImage;
-    
+
     mimeType = caja_file_info_get_mime_type (file);
-    
-    isImage = g_str_has_prefix (caja_file_info_get_mime_type (file), "image/");
-    
+    isImage = g_str_has_prefix (mimeType, "image/");
     g_free (mimeType);
-    
-    return isImage; 
+    return isImage;
 }
 
 
@@ -109,11 +105,11 @@ caja_cwe_get_file_items (CajaMenuProvider *provider,
                            _("Set as wallpaper"),
                            _("Set image as the current wallpaper"),
                            NULL);
-        g_signal_connect (item, 
+        g_signal_connect (item,
                   "activate",
                   G_CALLBACK (set_wallpaper_callback),
                 provider);
-        g_object_set_data_full (G_OBJECT (item), 
+        g_object_set_data_full (G_OBJECT (item),
                     "files",
                     caja_file_info_list_copy (files),
                     (GDestroyNotify) caja_file_info_list_free);
@@ -123,14 +119,14 @@ caja_cwe_get_file_items (CajaMenuProvider *provider,
 }
 
 
-static void 
+static void
 caja_cwe_menu_provider_iface_init (CajaMenuProviderIface *iface)
 {
     iface->get_file_items = caja_cwe_get_file_items;
 }
 
 
-static void 
+static void
 caja_cwe_instance_init (CajaCwe *cwe)
 {
 }
@@ -147,7 +143,7 @@ static GType cwe_type = 0;
 
 
 GType
-caja_cwe_get_type (void) 
+caja_cwe_get_type (void)
 {
     return cwe_type;
 }
@@ -161,7 +157,7 @@ caja_cwe_register_type (GTypeModule *module)
         (GBaseInitFunc) NULL,
         (GBaseFinalizeFunc) NULL,
         (GClassInitFunc) caja_cwe_class_init,
-        NULL, 
+        NULL,
         NULL,
         sizeof (CajaCwe),
         0,
